<?php

namespace App\Controller;

use Exception;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Http\Authentication\AuthenticationUtils;

/**
 * Controller about security (login / logout)
 *
 * @package App\Controller
 */
class SecurityController extends AbstractController {
    /**
     * Show login form
     *
     * @param AuthenticationUtils $authenticationUtils
     *
     * @return Response Page response
     *
     * @Route("/login")
     */
    public function login (AuthenticationUtils $authenticationUtils): Response {
        $error = $authenticationUtils->getLastAuthenticationError();
        $lastUsername = $authenticationUtils->getLastUsername();

        return $this->render(
            'security/login.html.twig',
            [
                'last_username' => $lastUsername,
                'error'         => $error,
            ]
        );
    }

    /**
     * *Perform* logout
     *
     * @throws Exception When firewall failed and this method is *really* called
     *
     * @Route("/logout")
     */
    public function logout () {
        throw new Exception('This method can be blank - it will be intercepted by the logout key on your firewall');
    }
}
